# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.manager_link_status_pb2 import (
    ManagerLinkStatusEnum as google___ads___googleads___v4___enums___manager_link_status_pb2___ManagerLinkStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerManagerLink(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v4___enums___manager_link_status_pb2___ManagerLinkStatusEnum.ManagerLinkStatusValue = ...
    @property
    def manager_customer(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def manager_link_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        manager_customer: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        manager_link_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___manager_link_status_pb2___ManagerLinkStatusEnum.ManagerLinkStatusValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "manager_customer",
            b"manager_customer",
            "manager_link_id",
            b"manager_link_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "manager_customer",
            b"manager_customer",
            "manager_link_id",
            b"manager_link_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

type___CustomerManagerLink = CustomerManagerLink



from typing import Any

class OfflineUserDataJobServiceStub:
    CreateOfflineUserDataJob: Any = ...
    GetOfflineUserDataJob: Any = ...
    AddOfflineUserDataJobOperations: Any = ...
    RunOfflineUserDataJob: Any = ...
    def __init__(self, channel: Any) -> None: ...

class OfflineUserDataJobServiceServicer:
    def CreateOfflineUserDataJob(self, request: Any, context: Any) -> None: ...
    def GetOfflineUserDataJob(self, request: Any, context: Any) -> None: ...
    def AddOfflineUserDataJobOperations(self, request: Any, context: Any) -> None: ...
    def RunOfflineUserDataJob(self, request: Any, context: Any) -> None: ...

def add_OfflineUserDataJobServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class CustomerFeedServiceStub:
    GetCustomerFeed: Any = ...
    MutateCustomerFeeds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerFeedServiceServicer:
    def GetCustomerFeed(self, request: Any, context: Any) -> None: ...
    def MutateCustomerFeeds(self, request: Any, context: Any) -> None: ...

def add_CustomerFeedServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import (
    Any,
    Callable,
    ClassVar,
    Dict,
    Iterable,
    List,
    Optional,
    Sequence,
    Tuple,
    Union,
)

import grpc  # type: ignore
from google.api_core.client_options import ClientOptions  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from google.auth.credentials import Credentials  # type: ignore
from google.oauth2 import service_account as service_account  # type: ignore

from google.ads.google_ads.v3.proto.services import (
    operating_system_version_constant_service_pb2 as operating_system_version_constant_service_pb2,
)
from google.ads.google_ads.v3.services import (
    operating_system_version_constant_service_client_config as operating_system_version_constant_service_client_config,
)
from google.ads.google_ads.v3.services.transports import (
    operating_system_version_constant_service_grpc_transport as operating_system_version_constant_service_grpc_transport,
)
from google.ads.google_ads.v3.types import OperatingSystemVersionConstant

class OperatingSystemVersionConstantServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(
        cls, filename: str, *args: Any, **kwargs: Any
    ) -> OperatingSystemVersionConstantServiceClient: ...
    @classmethod
    def from_service_account_json(
        cls, filename: str, *args: Any, **kwargs: Any
    ) -> OperatingSystemVersionConstantServiceClient: ...
    @classmethod
    def operating_system_version_constant_path(
        cls, operating_system_version_constant: Any
    ) -> str: ...
    transport: Union[
        operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport,
        Callable[
            [Credentials, type],
            operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport,
        ],
    ] = ...
    def __init__(
        self,
        transport: Optional[
            Union[
                operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport,
                Callable[
                    [Credentials, type],
                    operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport,
                ],
            ]
        ] = ...,
        channel: Optional[grpc.Channel] = ...,
        credentials: Optional[Credentials] = ...,
        client_config: Optional[Dict[str, Any]] = ...,
        client_info: Optional[ClientInfo] = ...,
    ) -> None: ...
    def get_operating_system_version_constant(
        self,
        resource_name: str,
        retry: Optional[Retry] = ...,
        timeout: Optional[float] = ...,
        metadata: Optional[Sequence[Tuple[str, str]]] = ...,
    ) -> OperatingSystemVersionConstant: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionAdjustmentUploadErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionAdjustmentUploadErrorValue = typing___NewType(
        "ConversionAdjustmentUploadErrorValue", builtin___int
    )
    type___ConversionAdjustmentUploadErrorValue = ConversionAdjustmentUploadErrorValue
    ConversionAdjustmentUploadError: _ConversionAdjustmentUploadError
    class _ConversionAdjustmentUploadError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 1
        )
        TOO_RECENT_CONVERSION_ACTION = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 2
        )
        INVALID_CONVERSION_ACTION = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 3
        )
        CONVERSION_ALREADY_RETRACTED = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 4
        )
        CONVERSION_NOT_FOUND = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 5
        )
        CONVERSION_EXPIRED = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 6
        )
        ADJUSTMENT_PRECEDES_CONVERSION = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 7
        )
        MORE_RECENT_RESTATEMENT_FOUND = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 8
        )
        TOO_RECENT_CONVERSION = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 9
        )
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 10
        )
        TOO_MANY_ADJUSTMENTS_IN_REQUEST = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 11
        )
        TOO_MANY_ADJUSTMENTS = typing___cast(
            ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 12
        )
    UNSPECIFIED = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 0
    )
    UNKNOWN = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 1
    )
    TOO_RECENT_CONVERSION_ACTION = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 2
    )
    INVALID_CONVERSION_ACTION = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 3
    )
    CONVERSION_ALREADY_RETRACTED = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 4
    )
    CONVERSION_NOT_FOUND = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 5
    )
    CONVERSION_EXPIRED = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 6
    )
    ADJUSTMENT_PRECEDES_CONVERSION = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 7
    )
    MORE_RECENT_RESTATEMENT_FOUND = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 8
    )
    TOO_RECENT_CONVERSION = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 9
    )
    CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 10
    )
    TOO_MANY_ADJUSTMENTS_IN_REQUEST = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 11
    )
    TOO_MANY_ADJUSTMENTS = typing___cast(
        ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorValue, 12
    )
    type___ConversionAdjustmentUploadError = ConversionAdjustmentUploadError
    def __init__(self,) -> None: ...

type___ConversionAdjustmentUploadErrorEnum = ConversionAdjustmentUploadErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerFeedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerFeedErrorValue = typing___NewType("CustomerFeedErrorValue", builtin___int)
    type___CustomerFeedErrorValue = CustomerFeedErrorValue
    CustomerFeedError: _CustomerFeedError
    class _CustomerFeedError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerFeedErrorEnum.CustomerFeedErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CustomerFeedErrorEnum.CustomerFeedErrorValue, 0)
        UNKNOWN = typing___cast(CustomerFeedErrorEnum.CustomerFeedErrorValue, 1)
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 2
        )
        CANNOT_CREATE_FOR_REMOVED_FEED = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 3
        )
        CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 4
        )
        CANNOT_MODIFY_REMOVED_CUSTOMER_FEED = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 5
        )
        INVALID_PLACEHOLDER_TYPE = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 6
        )
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 7
        )
        PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED = typing___cast(
            CustomerFeedErrorEnum.CustomerFeedErrorValue, 8
        )
    UNSPECIFIED = typing___cast(CustomerFeedErrorEnum.CustomerFeedErrorValue, 0)
    UNKNOWN = typing___cast(CustomerFeedErrorEnum.CustomerFeedErrorValue, 1)
    FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 2
    )
    CANNOT_CREATE_FOR_REMOVED_FEED = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 3
    )
    CANNOT_CREATE_ALREADY_EXISTING_CUSTOMER_FEED = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 4
    )
    CANNOT_MODIFY_REMOVED_CUSTOMER_FEED = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 5
    )
    INVALID_PLACEHOLDER_TYPE = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 6
    )
    MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 7
    )
    PLACEHOLDER_TYPE_NOT_ALLOWED_ON_CUSTOMER_FEED = typing___cast(
        CustomerFeedErrorEnum.CustomerFeedErrorValue, 8
    )
    type___CustomerFeedError = CustomerFeedError
    def __init__(self,) -> None: ...

type___CustomerFeedErrorEnum = CustomerFeedErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class NegativeGeoTargetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    NegativeGeoTargetTypeValue = typing___NewType(
        "NegativeGeoTargetTypeValue", builtin___int
    )
    type___NegativeGeoTargetTypeValue = NegativeGeoTargetTypeValue
    NegativeGeoTargetType: _NegativeGeoTargetType
    class _NegativeGeoTargetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 0
        )
        UNKNOWN = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 1)
        PRESENCE_OR_INTEREST = typing___cast(
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 4
        )
        PRESENCE = typing___cast(
            NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 5
        )
    UNSPECIFIED = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 0)
    UNKNOWN = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 1)
    PRESENCE_OR_INTEREST = typing___cast(
        NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 4
    )
    PRESENCE = typing___cast(NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue, 5)
    type___NegativeGeoTargetType = NegativeGeoTargetType
    def __init__(self,) -> None: ...

type___NegativeGeoTargetTypeEnum = NegativeGeoTargetTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedErrorValue = typing___NewType("FeedErrorValue", builtin___int)
    type___FeedErrorValue = FeedErrorValue
    FeedError: _FeedError
    class _FeedError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedErrorEnum.FeedErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedErrorEnum.FeedErrorValue, 0)
        UNKNOWN = typing___cast(FeedErrorEnum.FeedErrorValue, 1)
        ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedErrorValue, 2)
        ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(
            FeedErrorEnum.FeedErrorValue, 3
        )
        CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(
            FeedErrorEnum.FeedErrorValue, 4
        )
        CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(
            FeedErrorEnum.FeedErrorValue, 5
        )
        CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(
            FeedErrorEnum.FeedErrorValue, 6
        )
        CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(
            FeedErrorEnum.FeedErrorValue, 7
        )
        FEED_REMOVED = typing___cast(FeedErrorEnum.FeedErrorValue, 8)
        INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedErrorValue, 9)
        FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedErrorValue, 10)
        INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 11)
        INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 12)
        DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 13)
        INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 14)
        MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedErrorValue, 15)
        NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(
            FeedErrorEnum.FeedErrorValue, 16
        )
        TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedErrorValue, 17)
        INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedErrorValue, 18)
        BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(
            FeedErrorEnum.FeedErrorValue, 19
        )
        INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedErrorValue, 20)
        DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedErrorValue, 21)
        GMB_ACCESS_ERROR = typing___cast(FeedErrorEnum.FeedErrorValue, 22)
        CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = typing___cast(
            FeedErrorEnum.FeedErrorValue, 23
        )
    UNSPECIFIED = typing___cast(FeedErrorEnum.FeedErrorValue, 0)
    UNKNOWN = typing___cast(FeedErrorEnum.FeedErrorValue, 1)
    ATTRIBUTE_NAMES_NOT_UNIQUE = typing___cast(FeedErrorEnum.FeedErrorValue, 2)
    ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES = typing___cast(
        FeedErrorEnum.FeedErrorValue, 3
    )
    CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED = typing___cast(
        FeedErrorEnum.FeedErrorValue, 4
    )
    CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED = typing___cast(
        FeedErrorEnum.FeedErrorValue, 5
    )
    CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED = typing___cast(
        FeedErrorEnum.FeedErrorValue, 6
    )
    CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE = typing___cast(
        FeedErrorEnum.FeedErrorValue, 7
    )
    FEED_REMOVED = typing___cast(FeedErrorEnum.FeedErrorValue, 8)
    INVALID_ORIGIN_VALUE = typing___cast(FeedErrorEnum.FeedErrorValue, 9)
    FEED_ORIGIN_IS_NOT_USER = typing___cast(FeedErrorEnum.FeedErrorValue, 10)
    INVALID_AUTH_TOKEN_FOR_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 11)
    INVALID_EMAIL = typing___cast(FeedErrorEnum.FeedErrorValue, 12)
    DUPLICATE_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 13)
    INVALID_FEED_NAME = typing___cast(FeedErrorEnum.FeedErrorValue, 14)
    MISSING_OAUTH_INFO = typing___cast(FeedErrorEnum.FeedErrorValue, 15)
    NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY = typing___cast(
        FeedErrorEnum.FeedErrorValue, 16
    )
    TOO_MANY_ATTRIBUTES = typing___cast(FeedErrorEnum.FeedErrorValue, 17)
    INVALID_BUSINESS_ACCOUNT = typing___cast(FeedErrorEnum.FeedErrorValue, 18)
    BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT = typing___cast(
        FeedErrorEnum.FeedErrorValue, 19
    )
    INVALID_AFFILIATE_CHAIN_ID = typing___cast(FeedErrorEnum.FeedErrorValue, 20)
    DUPLICATE_SYSTEM_FEED = typing___cast(FeedErrorEnum.FeedErrorValue, 21)
    GMB_ACCESS_ERROR = typing___cast(FeedErrorEnum.FeedErrorValue, 22)
    CANNOT_HAVE_LOCATION_AND_AFFILIATE_LOCATION_FEEDS = typing___cast(
        FeedErrorEnum.FeedErrorValue, 23
    )
    type___FeedError = FeedError
    def __init__(self,) -> None: ...

type___FeedErrorEnum = FeedErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.click_location_pb2 import (
    ClickLocation as google___ads___googleads___v6___common___click_location_pb2___ClickLocation,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ClickView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    gclid: typing___Text = ...
    page_number: builtin___int = ...
    ad_group_ad: typing___Text = ...
    campaign_location_target: typing___Text = ...
    user_list: typing___Text = ...
    @property
    def area_of_interest(
        self,
    ) -> google___ads___googleads___v6___common___click_location_pb2___ClickLocation: ...
    @property
    def location_of_presence(
        self,
    ) -> google___ads___googleads___v6___common___click_location_pb2___ClickLocation: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        gclid: typing___Optional[typing___Text] = None,
        area_of_interest: typing___Optional[
            google___ads___googleads___v6___common___click_location_pb2___ClickLocation
        ] = None,
        location_of_presence: typing___Optional[
            google___ads___googleads___v6___common___click_location_pb2___ClickLocation
        ] = None,
        page_number: typing___Optional[builtin___int] = None,
        ad_group_ad: typing___Optional[typing___Text] = None,
        campaign_location_target: typing___Optional[typing___Text] = None,
        user_list: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_campaign_location_target",
            b"_campaign_location_target",
            "_gclid",
            b"_gclid",
            "_page_number",
            b"_page_number",
            "_user_list",
            b"_user_list",
            "ad_group_ad",
            b"ad_group_ad",
            "area_of_interest",
            b"area_of_interest",
            "campaign_location_target",
            b"campaign_location_target",
            "gclid",
            b"gclid",
            "location_of_presence",
            b"location_of_presence",
            "page_number",
            b"page_number",
            "user_list",
            b"user_list",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_campaign_location_target",
            b"_campaign_location_target",
            "_gclid",
            b"_gclid",
            "_page_number",
            b"_page_number",
            "_user_list",
            b"_user_list",
            "ad_group_ad",
            b"ad_group_ad",
            "area_of_interest",
            b"area_of_interest",
            "campaign_location_target",
            b"campaign_location_target",
            "gclid",
            b"gclid",
            "location_of_presence",
            b"location_of_presence",
            "page_number",
            b"page_number",
            "resource_name",
            b"resource_name",
            "user_list",
            b"user_list",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_ad_group_ad", b"_ad_group_ad"]
    ) -> typing_extensions___Literal["ad_group_ad"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_campaign_location_target", b"_campaign_location_target"
        ],
    ) -> typing_extensions___Literal["campaign_location_target"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_gclid", b"_gclid"]
    ) -> typing_extensions___Literal["gclid"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_page_number", b"_page_number"]
    ) -> typing_extensions___Literal["page_number"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_user_list", b"_user_list"]
    ) -> typing_extensions___Literal["user_list"]: ...

type___ClickView = ClickView



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupAdLabel(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    ad_group_ad: typing___Text = ...
    label: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        ad_group_ad: typing___Optional[typing___Text] = None,
        label: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_label",
            b"_label",
            "ad_group_ad",
            b"ad_group_ad",
            "label",
            b"label",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_label",
            b"_label",
            "ad_group_ad",
            b"ad_group_ad",
            "label",
            b"label",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_ad_group_ad", b"_ad_group_ad"]
    ) -> typing_extensions___Literal["ad_group_ad"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_label", b"_label"]
    ) -> typing_extensions___Literal["label"]: ...

type___AdGroupAdLabel = AdGroupAdLabel



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionActionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionActionErrorValue = typing___NewType(
        "ConversionActionErrorValue", builtin___int
    )
    type___ConversionActionErrorValue = ConversionActionErrorValue
    ConversionActionError: _ConversionActionError
    class _ConversionActionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionActionErrorEnum.ConversionActionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 0
        )
        UNKNOWN = typing___cast(ConversionActionErrorEnum.ConversionActionErrorValue, 1)
        DUPLICATE_NAME = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 2
        )
        DUPLICATE_APP_ID = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 3
        )
        TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 4
        )
        BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 5
        )
        DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 6
        )
        DATA_DRIVEN_MODEL_EXPIRED = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 7
        )
        DATA_DRIVEN_MODEL_STALE = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 8
        )
        DATA_DRIVEN_MODEL_UNKNOWN = typing___cast(
            ConversionActionErrorEnum.ConversionActionErrorValue, 9
        )
    UNSPECIFIED = typing___cast(ConversionActionErrorEnum.ConversionActionErrorValue, 0)
    UNKNOWN = typing___cast(ConversionActionErrorEnum.ConversionActionErrorValue, 1)
    DUPLICATE_NAME = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 2
    )
    DUPLICATE_APP_ID = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 3
    )
    TWO_CONVERSION_ACTIONS_BIDDING_ON_SAME_APP_DOWNLOAD = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 4
    )
    BIDDING_ON_SAME_APP_DOWNLOAD_AS_GLOBAL_ACTION = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 5
    )
    DATA_DRIVEN_MODEL_WAS_NEVER_GENERATED = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 6
    )
    DATA_DRIVEN_MODEL_EXPIRED = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 7
    )
    DATA_DRIVEN_MODEL_STALE = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 8
    )
    DATA_DRIVEN_MODEL_UNKNOWN = typing___cast(
        ConversionActionErrorEnum.ConversionActionErrorValue, 9
    )
    type___ConversionActionError = ConversionActionError
    def __init__(self,) -> None: ...

type___ConversionActionErrorEnum = ConversionActionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DeviceEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DeviceValue = typing___NewType("DeviceValue", builtin___int)
    type___DeviceValue = DeviceValue
    Device: _Device
    class _Device(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DeviceEnum.DeviceValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DeviceEnum.DeviceValue, 0)
        UNKNOWN = typing___cast(DeviceEnum.DeviceValue, 1)
        MOBILE = typing___cast(DeviceEnum.DeviceValue, 2)
        TABLET = typing___cast(DeviceEnum.DeviceValue, 3)
        DESKTOP = typing___cast(DeviceEnum.DeviceValue, 4)
        CONNECTED_TV = typing___cast(DeviceEnum.DeviceValue, 6)
        OTHER = typing___cast(DeviceEnum.DeviceValue, 5)
    UNSPECIFIED = typing___cast(DeviceEnum.DeviceValue, 0)
    UNKNOWN = typing___cast(DeviceEnum.DeviceValue, 1)
    MOBILE = typing___cast(DeviceEnum.DeviceValue, 2)
    TABLET = typing___cast(DeviceEnum.DeviceValue, 3)
    DESKTOP = typing___cast(DeviceEnum.DeviceValue, 4)
    CONNECTED_TV = typing___cast(DeviceEnum.DeviceValue, 6)
    OTHER = typing___cast(DeviceEnum.DeviceValue, 5)
    type___Device = Device
    def __init__(self,) -> None: ...

type___DeviceEnum = DeviceEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class QueryErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    QueryErrorValue = typing___NewType("QueryErrorValue", builtin___int)
    type___QueryErrorValue = QueryErrorValue
    QueryError: _QueryError
    class _QueryError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            QueryErrorEnum.QueryErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(QueryErrorEnum.QueryErrorValue, 0)
        UNKNOWN = typing___cast(QueryErrorEnum.QueryErrorValue, 1)
        QUERY_ERROR = typing___cast(QueryErrorEnum.QueryErrorValue, 50)
        BAD_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryErrorValue, 18)
        BAD_ESCAPE_SEQUENCE = typing___cast(QueryErrorEnum.QueryErrorValue, 7)
        BAD_FIELD_NAME = typing___cast(QueryErrorEnum.QueryErrorValue, 12)
        BAD_LIMIT_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 15)
        BAD_NUMBER = typing___cast(QueryErrorEnum.QueryErrorValue, 5)
        BAD_OPERATOR = typing___cast(QueryErrorEnum.QueryErrorValue, 3)
        BAD_PARAMETER_NAME = typing___cast(QueryErrorEnum.QueryErrorValue, 61)
        BAD_PARAMETER_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 62)
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 45
        )
        BAD_SYMBOL = typing___cast(QueryErrorEnum.QueryErrorValue, 2)
        BAD_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 4)
        DATE_RANGE_TOO_WIDE = typing___cast(QueryErrorEnum.QueryErrorValue, 36)
        DATE_RANGE_TOO_NARROW = typing___cast(QueryErrorEnum.QueryErrorValue, 60)
        EXPECTED_AND = typing___cast(QueryErrorEnum.QueryErrorValue, 30)
        EXPECTED_BY = typing___cast(QueryErrorEnum.QueryErrorValue, 14)
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 37
        )
        EXPECTED_FILTERS_ON_DATE_RANGE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 55
        )
        EXPECTED_FROM = typing___cast(QueryErrorEnum.QueryErrorValue, 44)
        EXPECTED_LIST = typing___cast(QueryErrorEnum.QueryErrorValue, 41)
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 16
        )
        EXPECTED_SELECT = typing___cast(QueryErrorEnum.QueryErrorValue, 13)
        EXPECTED_SINGLE_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 42)
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(
            QueryErrorEnum.QueryErrorValue, 29
        )
        INVALID_DATE_FORMAT = typing___cast(QueryErrorEnum.QueryErrorValue, 38)
        INVALID_STRING_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 57)
        INVALID_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(
            QueryErrorEnum.QueryErrorValue, 26
        )
        INVALID_VALUE_WITH_DURING_OPERATOR = typing___cast(
            QueryErrorEnum.QueryErrorValue, 22
        )
        INVALID_VALUE_WITH_LIKE_OPERATOR = typing___cast(
            QueryErrorEnum.QueryErrorValue, 56
        )
        OPERATOR_FIELD_MISMATCH = typing___cast(QueryErrorEnum.QueryErrorValue, 35)
        PROHIBITED_EMPTY_LIST_IN_CONDITION = typing___cast(
            QueryErrorEnum.QueryErrorValue, 28
        )
        PROHIBITED_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryErrorValue, 54)
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 31
        )
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 40
        )
        PROHIBITED_FIELD_IN_SELECT_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 23
        )
        PROHIBITED_FIELD_IN_WHERE_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 24
        )
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 43
        )
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 48
        )
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 58
        )
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 49
        )
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 51
        )
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(
            QueryErrorEnum.QueryErrorValue, 53
        )
        LIMIT_VALUE_TOO_LOW = typing___cast(QueryErrorEnum.QueryErrorValue, 25)
        PROHIBITED_NEWLINE_IN_STRING = typing___cast(QueryErrorEnum.QueryErrorValue, 8)
        PROHIBITED_VALUE_COMBINATION_IN_LIST = typing___cast(
            QueryErrorEnum.QueryErrorValue, 10
        )
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = typing___cast(
            QueryErrorEnum.QueryErrorValue, 21
        )
        STRING_NOT_TERMINATED = typing___cast(QueryErrorEnum.QueryErrorValue, 6)
        TOO_MANY_SEGMENTS = typing___cast(QueryErrorEnum.QueryErrorValue, 34)
        UNEXPECTED_END_OF_QUERY = typing___cast(QueryErrorEnum.QueryErrorValue, 9)
        UNEXPECTED_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryErrorValue, 47)
        UNRECOGNIZED_FIELD = typing___cast(QueryErrorEnum.QueryErrorValue, 32)
        UNEXPECTED_INPUT = typing___cast(QueryErrorEnum.QueryErrorValue, 11)
        REQUESTED_METRICS_FOR_MANAGER = typing___cast(
            QueryErrorEnum.QueryErrorValue, 59
        )
    UNSPECIFIED = typing___cast(QueryErrorEnum.QueryErrorValue, 0)
    UNKNOWN = typing___cast(QueryErrorEnum.QueryErrorValue, 1)
    QUERY_ERROR = typing___cast(QueryErrorEnum.QueryErrorValue, 50)
    BAD_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryErrorValue, 18)
    BAD_ESCAPE_SEQUENCE = typing___cast(QueryErrorEnum.QueryErrorValue, 7)
    BAD_FIELD_NAME = typing___cast(QueryErrorEnum.QueryErrorValue, 12)
    BAD_LIMIT_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 15)
    BAD_NUMBER = typing___cast(QueryErrorEnum.QueryErrorValue, 5)
    BAD_OPERATOR = typing___cast(QueryErrorEnum.QueryErrorValue, 3)
    BAD_PARAMETER_NAME = typing___cast(QueryErrorEnum.QueryErrorValue, 61)
    BAD_PARAMETER_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 62)
    BAD_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryErrorValue, 45)
    BAD_SYMBOL = typing___cast(QueryErrorEnum.QueryErrorValue, 2)
    BAD_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 4)
    DATE_RANGE_TOO_WIDE = typing___cast(QueryErrorEnum.QueryErrorValue, 36)
    DATE_RANGE_TOO_NARROW = typing___cast(QueryErrorEnum.QueryErrorValue, 60)
    EXPECTED_AND = typing___cast(QueryErrorEnum.QueryErrorValue, 30)
    EXPECTED_BY = typing___cast(QueryErrorEnum.QueryErrorValue, 14)
    EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 37
    )
    EXPECTED_FILTERS_ON_DATE_RANGE = typing___cast(QueryErrorEnum.QueryErrorValue, 55)
    EXPECTED_FROM = typing___cast(QueryErrorEnum.QueryErrorValue, 44)
    EXPECTED_LIST = typing___cast(QueryErrorEnum.QueryErrorValue, 41)
    EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 16
    )
    EXPECTED_SELECT = typing___cast(QueryErrorEnum.QueryErrorValue, 13)
    EXPECTED_SINGLE_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 42)
    EXPECTED_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(
        QueryErrorEnum.QueryErrorValue, 29
    )
    INVALID_DATE_FORMAT = typing___cast(QueryErrorEnum.QueryErrorValue, 38)
    INVALID_STRING_VALUE = typing___cast(QueryErrorEnum.QueryErrorValue, 57)
    INVALID_VALUE_WITH_BETWEEN_OPERATOR = typing___cast(
        QueryErrorEnum.QueryErrorValue, 26
    )
    INVALID_VALUE_WITH_DURING_OPERATOR = typing___cast(
        QueryErrorEnum.QueryErrorValue, 22
    )
    INVALID_VALUE_WITH_LIKE_OPERATOR = typing___cast(QueryErrorEnum.QueryErrorValue, 56)
    OPERATOR_FIELD_MISMATCH = typing___cast(QueryErrorEnum.QueryErrorValue, 35)
    PROHIBITED_EMPTY_LIST_IN_CONDITION = typing___cast(
        QueryErrorEnum.QueryErrorValue, 28
    )
    PROHIBITED_ENUM_CONSTANT = typing___cast(QueryErrorEnum.QueryErrorValue, 54)
    PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 31
    )
    PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 40
    )
    PROHIBITED_FIELD_IN_SELECT_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 23
    )
    PROHIBITED_FIELD_IN_WHERE_CLAUSE = typing___cast(QueryErrorEnum.QueryErrorValue, 24)
    PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 43
    )
    PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 48
    )
    PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 58
    )
    PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 49
    )
    PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 51
    )
    PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE = typing___cast(
        QueryErrorEnum.QueryErrorValue, 53
    )
    LIMIT_VALUE_TOO_LOW = typing___cast(QueryErrorEnum.QueryErrorValue, 25)
    PROHIBITED_NEWLINE_IN_STRING = typing___cast(QueryErrorEnum.QueryErrorValue, 8)
    PROHIBITED_VALUE_COMBINATION_IN_LIST = typing___cast(
        QueryErrorEnum.QueryErrorValue, 10
    )
    PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR = typing___cast(
        QueryErrorEnum.QueryErrorValue, 21
    )
    STRING_NOT_TERMINATED = typing___cast(QueryErrorEnum.QueryErrorValue, 6)
    TOO_MANY_SEGMENTS = typing___cast(QueryErrorEnum.QueryErrorValue, 34)
    UNEXPECTED_END_OF_QUERY = typing___cast(QueryErrorEnum.QueryErrorValue, 9)
    UNEXPECTED_FROM_CLAUSE = typing___cast(QueryErrorEnum.QueryErrorValue, 47)
    UNRECOGNIZED_FIELD = typing___cast(QueryErrorEnum.QueryErrorValue, 32)
    UNEXPECTED_INPUT = typing___cast(QueryErrorEnum.QueryErrorValue, 11)
    REQUESTED_METRICS_FOR_MANAGER = typing___cast(QueryErrorEnum.QueryErrorValue, 59)
    type___QueryError = QueryError
    def __init__(self,) -> None: ...

type___QueryErrorEnum = QueryErrorEnum



from typing import Any, Optional

class DisplayKeywordViewServiceStub:
    GetDisplayKeywordView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DisplayKeywordViewServiceServicer:
    def GetDisplayKeywordView(self, request: Any, context: Any) -> None: ...

def add_DisplayKeywordViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class DisplayKeywordViewService:
    @staticmethod
    def GetDisplayKeywordView(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



from typing import Any

class CustomerManagerLinkServiceStub:
    GetCustomerManagerLink: Any = ...
    MutateCustomerManagerLink: Any = ...
    MoveManagerLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomerManagerLinkServiceServicer:
    def GetCustomerManagerLink(self, request: Any, context: Any) -> None: ...
    def MutateCustomerManagerLink(self, request: Any, context: Any) -> None: ...
    def MoveManagerLink(self, request: Any, context: Any) -> None: ...

def add_CustomerManagerLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SettingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SettingErrorValue = typing___NewType("SettingErrorValue", builtin___int)
    type___SettingErrorValue = SettingErrorValue
    SettingError: _SettingError
    class _SettingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SettingErrorEnum.SettingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SettingErrorEnum.SettingErrorValue, 0)
        UNKNOWN = typing___cast(SettingErrorEnum.SettingErrorValue, 1)
        SETTING_TYPE_IS_NOT_AVAILABLE = typing___cast(
            SettingErrorEnum.SettingErrorValue, 3
        )
        SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN = typing___cast(
            SettingErrorEnum.SettingErrorValue, 4
        )
        TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP = typing___cast(
            SettingErrorEnum.SettingErrorValue, 5
        )
        TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL = typing___cast(
            SettingErrorEnum.SettingErrorValue, 6
        )
        TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP = typing___cast(
            SettingErrorEnum.SettingErrorValue, 7
        )
        DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT = typing___cast(
            SettingErrorEnum.SettingErrorValue, 8
        )
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME = typing___cast(
            SettingErrorEnum.SettingErrorValue, 9
        )
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME = typing___cast(
            SettingErrorEnum.SettingErrorValue, 10
        )
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE = typing___cast(
            SettingErrorEnum.SettingErrorValue, 11
        )
        TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN = typing___cast(
            SettingErrorEnum.SettingErrorValue, 12
        )
        SETTING_VALUE_NOT_COMPATIBLE_WITH_CAMPAIGN = typing___cast(
            SettingErrorEnum.SettingErrorValue, 20
        )
    UNSPECIFIED = typing___cast(SettingErrorEnum.SettingErrorValue, 0)
    UNKNOWN = typing___cast(SettingErrorEnum.SettingErrorValue, 1)
    SETTING_TYPE_IS_NOT_AVAILABLE = typing___cast(SettingErrorEnum.SettingErrorValue, 3)
    SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN = typing___cast(
        SettingErrorEnum.SettingErrorValue, 4
    )
    TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP = typing___cast(
        SettingErrorEnum.SettingErrorValue, 5
    )
    TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL = typing___cast(
        SettingErrorEnum.SettingErrorValue, 6
    )
    TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP = typing___cast(
        SettingErrorEnum.SettingErrorValue, 7
    )
    DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT = typing___cast(
        SettingErrorEnum.SettingErrorValue, 8
    )
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME = typing___cast(
        SettingErrorEnum.SettingErrorValue, 9
    )
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME = typing___cast(
        SettingErrorEnum.SettingErrorValue, 10
    )
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE = typing___cast(
        SettingErrorEnum.SettingErrorValue, 11
    )
    TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN = typing___cast(
        SettingErrorEnum.SettingErrorValue, 12
    )
    SETTING_VALUE_NOT_COMPATIBLE_WITH_CAMPAIGN = typing___cast(
        SettingErrorEnum.SettingErrorValue, 20
    )
    type___SettingError = SettingError
    def __init__(self,) -> None: ...

type___SettingErrorEnum = SettingErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.manager_link_status_pb2 import (
    ManagerLinkStatusEnum as google___ads___googleads___v6___enums___manager_link_status_pb2___ManagerLinkStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerManagerLink(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    manager_customer: typing___Text = ...
    manager_link_id: builtin___int = ...
    status: google___ads___googleads___v6___enums___manager_link_status_pb2___ManagerLinkStatusEnum.ManagerLinkStatusValue = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        manager_customer: typing___Optional[typing___Text] = None,
        manager_link_id: typing___Optional[builtin___int] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___manager_link_status_pb2___ManagerLinkStatusEnum.ManagerLinkStatusValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_manager_customer",
            b"_manager_customer",
            "_manager_link_id",
            b"_manager_link_id",
            "manager_customer",
            b"manager_customer",
            "manager_link_id",
            b"manager_link_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_manager_customer",
            b"_manager_customer",
            "_manager_link_id",
            b"_manager_link_id",
            "manager_customer",
            b"manager_customer",
            "manager_link_id",
            b"manager_link_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_manager_customer", b"_manager_customer"
        ],
    ) -> typing_extensions___Literal["manager_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_manager_link_id", b"_manager_link_id"
        ],
    ) -> typing_extensions___Literal["manager_link_id"]: ...

type___CustomerManagerLink = CustomerManagerLink



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UrlFieldErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UrlFieldErrorValue = typing___NewType("UrlFieldErrorValue", builtin___int)
    type___UrlFieldErrorValue = UrlFieldErrorValue
    UrlFieldError: _UrlFieldError
    class _UrlFieldError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UrlFieldErrorEnum.UrlFieldErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 0)
        UNKNOWN = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 1)
        INVALID_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 2
        )
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 3
        )
        MISSING_TRACKING_URL_TEMPLATE_TAG = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 4
        )
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 5
        )
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 6
        )
        MALFORMED_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 7
        )
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 8
        )
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 9
        )
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 10
        )
        INVALID_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 11)
        INVALID_TAG_IN_FINAL_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 12
        )
        REDUNDANT_NESTED_FINAL_URL_TAG = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 13
        )
        MISSING_PROTOCOL_IN_FINAL_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 14
        )
        INVALID_PROTOCOL_IN_FINAL_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 15
        )
        MALFORMED_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 16)
        MISSING_HOST_IN_FINAL_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 17
        )
        INVALID_TLD_IN_FINAL_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 18
        )
        INVALID_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 19
        )
        INVALID_TAG_IN_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 20
        )
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 21
        )
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 22
        )
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 23
        )
        MALFORMED_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 24
        )
        MISSING_HOST_IN_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 25
        )
        INVALID_TLD_IN_FINAL_MOBILE_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 26
        )
        INVALID_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 27)
        INVALID_TAG_IN_FINAL_APP_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 28
        )
        REDUNDANT_NESTED_FINAL_APP_URL_TAG = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 29
        )
        MULTIPLE_APP_URLS_FOR_OSTYPE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 30
        )
        INVALID_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 31)
        INVALID_PROTOCOL_FOR_APP_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 32
        )
        INVALID_PACKAGE_ID_FOR_APP_URL = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 33
        )
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 34
        )
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 39
        )
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 40
        )
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 41
        )
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 42
        )
        MISSING_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 43)
        INVALID_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 52)
        INVALID_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 44)
        DESTINATION_URL_DEPRECATED = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 45
        )
        INVALID_TAG_IN_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 46)
        MISSING_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 47)
        DUPLICATE_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 48)
        INVALID_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 49)
        FINAL_URL_SUFFIX_MALFORMED = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 50
        )
        INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 51
        )
        INVALID_TOP_LEVEL_DOMAIN = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 53
        )
        MALFORMED_TOP_LEVEL_DOMAIN = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 54
        )
        MALFORMED_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 55)
        MISSING_HOST = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 56)
        NULL_CUSTOM_PARAMETER_VALUE = typing___cast(
            UrlFieldErrorEnum.UrlFieldErrorValue, 57
        )
    UNSPECIFIED = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 0)
    UNKNOWN = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 1)
    INVALID_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 2
    )
    INVALID_TAG_IN_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 3
    )
    MISSING_TRACKING_URL_TEMPLATE_TAG = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 4
    )
    MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 5
    )
    INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 6
    )
    MALFORMED_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 7
    )
    MISSING_HOST_IN_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 8
    )
    INVALID_TLD_IN_TRACKING_URL_TEMPLATE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 9
    )
    REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 10
    )
    INVALID_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 11)
    INVALID_TAG_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 12)
    REDUNDANT_NESTED_FINAL_URL_TAG = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 13
    )
    MISSING_PROTOCOL_IN_FINAL_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 14
    )
    INVALID_PROTOCOL_IN_FINAL_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 15
    )
    MALFORMED_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 16)
    MISSING_HOST_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 17)
    INVALID_TLD_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 18)
    INVALID_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 19)
    INVALID_TAG_IN_FINAL_MOBILE_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 20
    )
    REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 21
    )
    MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 22
    )
    INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 23
    )
    MALFORMED_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 24)
    MISSING_HOST_IN_FINAL_MOBILE_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 25
    )
    INVALID_TLD_IN_FINAL_MOBILE_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 26
    )
    INVALID_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 27)
    INVALID_TAG_IN_FINAL_APP_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 28
    )
    REDUNDANT_NESTED_FINAL_APP_URL_TAG = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 29
    )
    MULTIPLE_APP_URLS_FOR_OSTYPE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 30
    )
    INVALID_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 31)
    INVALID_PROTOCOL_FOR_APP_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 32
    )
    INVALID_PACKAGE_ID_FOR_APP_URL = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 33
    )
    URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 34
    )
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 39
    )
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 40
    )
    INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 41
    )
    REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 42
    )
    MISSING_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 43)
    INVALID_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 52)
    INVALID_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 44)
    DESTINATION_URL_DEPRECATED = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 45)
    INVALID_TAG_IN_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 46)
    MISSING_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 47)
    DUPLICATE_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 48)
    INVALID_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 49)
    FINAL_URL_SUFFIX_MALFORMED = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 50)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 51
    )
    INVALID_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 53)
    MALFORMED_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 54)
    MALFORMED_URL = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 55)
    MISSING_HOST = typing___cast(UrlFieldErrorEnum.UrlFieldErrorValue, 56)
    NULL_CUSTOM_PARAMETER_VALUE = typing___cast(
        UrlFieldErrorEnum.UrlFieldErrorValue, 57
    )
    type___UrlFieldError = UrlFieldError
    def __init__(self,) -> None: ...

type___UrlFieldErrorEnum = UrlFieldErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class JobPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    JobPlaceholderFieldValue = typing___NewType(
        "JobPlaceholderFieldValue", builtin___int
    )
    type___JobPlaceholderFieldValue = JobPlaceholderFieldValue
    JobPlaceholderField: _JobPlaceholderField
    class _JobPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 0)
        UNKNOWN = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 1)
        JOB_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 2)
        LOCATION_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 3)
        TITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 4)
        SUBTITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 5)
        DESCRIPTION = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 6)
        IMAGE_URL = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 7)
        CATEGORY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 8)
        CONTEXTUAL_KEYWORDS = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 9
        )
        ADDRESS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 10)
        SALARY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 11)
        FINAL_URLS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 12)
        FINAL_MOBILE_URLS = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 14
        )
        TRACKING_URL = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 15
        )
        ANDROID_APP_LINK = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 16
        )
        SIMILAR_JOB_IDS = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 17
        )
        IOS_APP_LINK = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 18
        )
        IOS_APP_STORE_ID = typing___cast(
            JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 19
        )
    UNSPECIFIED = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 1)
    JOB_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 2)
    LOCATION_ID = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 3)
    TITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 4)
    SUBTITLE = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 5)
    DESCRIPTION = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 6)
    IMAGE_URL = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 7)
    CATEGORY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 8)
    CONTEXTUAL_KEYWORDS = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 9
    )
    ADDRESS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 10)
    SALARY = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 11)
    FINAL_URLS = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 12)
    FINAL_MOBILE_URLS = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 14
    )
    TRACKING_URL = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 15)
    ANDROID_APP_LINK = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 16
    )
    SIMILAR_JOB_IDS = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 17
    )
    IOS_APP_LINK = typing___cast(JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 18)
    IOS_APP_STORE_ID = typing___cast(
        JobPlaceholderFieldEnum.JobPlaceholderFieldValue, 19
    )
    type___JobPlaceholderField = JobPlaceholderField
    def __init__(self,) -> None: ...

type___JobPlaceholderFieldEnum = JobPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.campaign_experiment_status_pb2 import (
    CampaignExperimentStatusEnum as google___ads___googleads___v6___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.campaign_experiment_traffic_split_type_pb2 import (
    CampaignExperimentTrafficSplitTypeEnum as google___ads___googleads___v6___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignExperiment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    campaign_draft: typing___Text = ...
    name: typing___Text = ...
    description: typing___Text = ...
    traffic_split_percent: builtin___int = ...
    traffic_split_type: google___ads___googleads___v6___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitTypeValue = ...
    experiment_campaign: typing___Text = ...
    status: google___ads___googleads___v6___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatusValue = ...
    long_running_operation: typing___Text = ...
    start_date: typing___Text = ...
    end_date: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        campaign_draft: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        description: typing___Optional[typing___Text] = None,
        traffic_split_percent: typing___Optional[builtin___int] = None,
        traffic_split_type: typing___Optional[
            google___ads___googleads___v6___enums___campaign_experiment_traffic_split_type_pb2___CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitTypeValue
        ] = None,
        experiment_campaign: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___campaign_experiment_status_pb2___CampaignExperimentStatusEnum.CampaignExperimentStatusValue
        ] = None,
        long_running_operation: typing___Optional[typing___Text] = None,
        start_date: typing___Optional[typing___Text] = None,
        end_date: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign_draft",
            b"_campaign_draft",
            "_description",
            b"_description",
            "_end_date",
            b"_end_date",
            "_experiment_campaign",
            b"_experiment_campaign",
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "_start_date",
            b"_start_date",
            "_traffic_split_percent",
            b"_traffic_split_percent",
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "start_date",
            b"start_date",
            "traffic_split_percent",
            b"traffic_split_percent",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign_draft",
            b"_campaign_draft",
            "_description",
            b"_description",
            "_end_date",
            b"_end_date",
            "_experiment_campaign",
            b"_experiment_campaign",
            "_id",
            b"_id",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "_start_date",
            b"_start_date",
            "_traffic_split_percent",
            b"_traffic_split_percent",
            "campaign_draft",
            b"campaign_draft",
            "description",
            b"description",
            "end_date",
            b"end_date",
            "experiment_campaign",
            b"experiment_campaign",
            "id",
            b"id",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "traffic_split_percent",
            b"traffic_split_percent",
            "traffic_split_type",
            b"traffic_split_type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_campaign_draft", b"_campaign_draft"],
    ) -> typing_extensions___Literal["campaign_draft"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_description", b"_description"]
    ) -> typing_extensions___Literal["description"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_end_date", b"_end_date"]
    ) -> typing_extensions___Literal["end_date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_experiment_campaign", b"_experiment_campaign"
        ],
    ) -> typing_extensions___Literal["experiment_campaign"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions___Literal["long_running_operation"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_start_date", b"_start_date"]
    ) -> typing_extensions___Literal["start_date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_traffic_split_percent", b"_traffic_split_percent"
        ],
    ) -> typing_extensions___Literal["traffic_split_percent"]: ...

type___CampaignExperiment = CampaignExperiment



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DataDrivenModelStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DataDrivenModelStatusValue = typing___NewType(
        "DataDrivenModelStatusValue", builtin___int
    )
    type___DataDrivenModelStatusValue = DataDrivenModelStatusValue
    DataDrivenModelStatus: _DataDrivenModelStatus
    class _DataDrivenModelStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DataDrivenModelStatusEnum.DataDrivenModelStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 0
        )
        UNKNOWN = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 1)
        AVAILABLE = typing___cast(
            DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 2
        )
        STALE = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 3)
        EXPIRED = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 4)
        NEVER_GENERATED = typing___cast(
            DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 5
        )
    UNSPECIFIED = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 0)
    UNKNOWN = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 1)
    AVAILABLE = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 2)
    STALE = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 3)
    EXPIRED = typing___cast(DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 4)
    NEVER_GENERATED = typing___cast(
        DataDrivenModelStatusEnum.DataDrivenModelStatusValue, 5
    )
    type___DataDrivenModelStatus = DataDrivenModelStatus
    def __init__(self,) -> None: ...

type___DataDrivenModelStatusEnum = DataDrivenModelStatusEnum
